// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#ifndef FIELD_H
#define FIELD_H

#include <QLabel>
#include <QWidget>
#include <QStackedLayout>
#include "src/Monopd/monopdgame.h"
#include "src/Monopd/monopdfield.h"
#include "cmdtoolbutton.h"
#include "auction.h"

namespace Ui {
	class Field;
}

class Field : public QWidget {
	Q_OBJECT

	public:
		Field(QWidget* parent=0);
		void setGame(MonopdGame* g);
		~Field();
		Auction* auction;

	private:
		Ui::Field *ui;
		MonopdGame* game;
		QRect getAvatarRect(int pos);
		QRect getFieldRect(int pos);
		QStackedLayout* stack;
		QLabel* text;
		QList<CmdToolButton*> buttons;
		MonopdField* selectedField;

	protected:
		void changeEvent(QEvent* e);
		void mousePressEvent(QMouseEvent* event);

	private slots:
		void emitButtonClick(QString cmd);

	public slots:
		void appendLine(QString txt);
		void addButton(QString text, QString cmd);
		void clearText();
		void clearButtons();
		void addPlayerAuction(Player* p);

		void showAuction();
		void updatAuctionId(int aid);
		void updateAuctionField(int fid);
		void bidUpdate(int pid, int bid);
		void updateAuctionStatus(int status);

	signals:
		void buttonClicked(QString cmd);
		void fieldSelected(MonopdField* f);

	protected:
		void paintEvent(QPaintEvent* pe);
};

#endif // FIELD_H
